pub async fn delete_role( db: &Pool<Postgres>, role_name: &str, ) -> Result<(), Error>
Delete a database role.
Running this requires using an account with a higher level of access than the standard db user