PresignedUploadTask

Struct PresignedUploadTask 

pub struct PresignedUploadTask {
Show 13 fields pub id: Uuid, pub status: PresignedTaskStatus, pub name: String, pub mime: String, pub size: i32, pub document_box: String, pub folder_id: Uuid, pub file_key: String, pub created_at: DateTime<Utc>, pub expires_at: DateTime<Utc>, pub created_by: Option<String>, pub parent_id: Option<Uuid>, pub processing_config: Option<Json<Value>>,
}
Task storing the details for a presigned upload task

Fields

id: Uuid

ID of the upload task

status: PresignedTaskStatus

File created from the outcome of this task

name: String

Name of the file being uploaded

mime: String

Mime type of the file being uploaded

size: i32

Expected size in bytes of the file

document_box: String

ID of the document box the folder belongs to

folder_id: Uuid

Target folder to store the file in

file_key: String

S3 key where the file should be stored

created_at: DateTime<Utc>

Creation timestamp of the upload task

expires_at: DateTime<Utc>

Timestamp of when the presigned URL will expire (Used as the date for background cleanup, to ensure that all files)

created_by: Option<String>

User who created the file

parent_id: Option<Uuid>

Optional file to make the parent of this file

processing_config: Option<Json<Value>>

Config that can be used when processing for additional configuration to how the file is processed

Implementations

Source

impl PresignedUploadTask

pub async fn create( db: impl PgExecutor<'_>, create: CreatePresignedUploadTask, ) -> Result<PresignedUploadTask, Error>

Create a new presigned upload task

pub async fn set_status( &mut self, db: impl PgExecutor<'_>, status: PresignedTaskStatus, ) -> Result<(), Error>

pub async fn find( db: impl PgExecutor<'_>, scope: &String, task_id: Uuid, ) -> Result<Option<PresignedUploadTask>, Error>

Find a specific presigned upload task

pub async fn find_expired( db: impl PgExecutor<'_>, current_date: DateTime<Utc>, ) -> Result<Vec<PresignedUploadTask>, Error>

Finds all presigned uploads that have expired based on the current date

pub async fn find_by_file_key( db: impl PgExecutor<'_>, file_key: &str, ) -> Result<Option<PresignedUploadTask>, Error>

Find a specific presigned upload task

pub async fn delete( db: impl PgExecutor<'_>, task_id: Uuid, ) -> Result<PgQueryResult, Error>

Delete a specific presigned upload task