pub struct ResolveWebsiteConfig {
pub metadata_cache_duration: TimeDelta,
}Expand description
Configuration for caching data in the website metadata service cache
Fields
metadata_cache_duration: TimeDeltaDuration to maintain site metadata for
Default: 48h
Implementations
Sourceimpl ResolveWebsiteConfig
impl ResolveWebsiteConfig
Sourcepub fn from_env() -> Result<ResolveWebsiteConfig, ResolveWebsiteConfigError>
pub fn from_env() -> Result<ResolveWebsiteConfig, ResolveWebsiteConfigError>
Load a website meta service config from its environment variables